==> react-molecule-image-editor-1.5.0.tgz: package/lib/index.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { useCallback, useState } from 'react';
import Cropper from 'react-easy-crop';
import PropTypes from 'prop-types';
import AtomSlider from '@s-ui/react-atom-slider';
import getCroppedImg from './utils/cropImage.js';
import { baseClass, DEFAULT_ASPECT, noop } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var MoleculeImageEditor = function MoleculeImageEditor(_ref) {
  var _ref$aspect = _ref.aspect,
      aspect = _ref$aspect === void 0 ? DEFAULT_ASPECT : _ref$aspect,
      cropLabelIcon = _ref.cropLabelIcon,
      cropLabelText = _ref.cropLabelText,
      image = _ref.image,
      onChange = _ref.onChange,
      _ref$onCropping = _ref.onCropping,
      onCropping = _ref$onCropping === void 0 ? noop : _ref$onCropping,
      rotateLabelIcon = _ref.rotateLabelIcon,
      rotateLabelText = _ref.rotateLabelText;

  var _useState = useState({
    x: 0,
    y: 0
  }),
      crop = _useState[0],
      setCrop = _useState[1];

  var _useState2 = useState(0),
      rotation = _useState2[0],
      setRotation = _useState2[1];

  var _useState3 = useState(0),
      zoom = _useState3[0],
      setZoom = _useState3[1];

  var getRotationDegrees = function getRotationDegrees(rotation) {
    return rotation * 360 / 100;
  };

  var onCropComplete = useCallback( /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(croppedArea, croppedAreaPixels) {
      var rotationDegrees, _yield$getCroppedImg, croppedImageUrl, croppedImageBlobObject;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              rotationDegrees = getRotationDegrees(rotation);
              onCropping(true);
              _context.next = 4;
              return getCroppedImg(image, croppedAreaPixels, rotationDegrees);

            case 4:
              _yield$getCroppedImg = _context.sent;
              croppedImageUrl = _yield$getCroppedImg[0];
              croppedImageBlobObject = _yield$getCroppedImg[1];
              onChange(croppedImageUrl, croppedImageBlobObject);
              onCropping(false);

            case 9:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function (_x, _x2) {
      return _ref2.apply(this, arguments);
    };
  }(), [rotation, onCropping, image, onChange]);
  return /*#__PURE__*/_jsxs("div", {
    className: baseClass,
    children: [/*#__PURE__*/_jsx("div", {
      className: baseClass + "-crop",
      children: /*#__PURE__*/_jsx(Cropper, {
        image: image,
        crop: crop,
        zoom: 1 + zoom / 100,
        rotation: getRotationDegrees(rotation),
        aspect: aspect,
        onCropChange: setCrop,
        onCropComplete: onCropComplete,
        onRotationChange: setRotation,
        onZoomChange: function onZoomChange(zoom) {
          return setZoom((zoom - 1) * 100);
        }
      })
    }), /*#__PURE__*/_jsxs("div", {
      className: baseClass + "-slider",
      children: [(cropLabelIcon || cropLabelText) && /*#__PURE__*/_jsxs("div", {
        className: baseClass + "-label",
        children: [cropLabelIcon && /*#__PURE__*/_jsx("span", {
          className: baseClass + "-labelIcon",
          children: cropLabelIcon
        }), cropLabelText && /*#__PURE__*/_jsx("span", {
          className: baseClass + "-labelText",
          children: cropLabelText
        })]
      }), /*#__PURE__*/_jsx(AtomSlider, {
        onChange: function onChange(event, _ref3) {
          var value = _ref3.value;
          return setZoom(value);
        },
        value: zoom,
        hideMarks: true
      })]
    }), /*#__PURE__*/_jsxs("div", {
      className: baseClass + "-slider",
      children: [(rotateLabelIcon || rotateLabelText) && /*#__PURE__*/_jsxs("div", {
        className: baseClass + "-label",
        children: [rotateLabelIcon && /*#__PURE__*/_jsx("span", {
          className: baseClass + "-labelIcon",
          children: rotateLabelIcon
        }), rotateLabelText && /*#__PURE__*/_jsx("span", {
          className: baseClass + "-labelText",
          children: rotateLabelText
        })]
      }), /*#__PURE__*/_jsx(AtomSlider, {
        onChange: function onChange(event, _ref4) {
          var value = _ref4.value;
          return setRotation(value);
        },
        value: rotation,
        hideMarks: true
      })]
    })]
  });
};

MoleculeImageEditor.displayName = 'MoleculeImageEditor';
export default MoleculeImageEditor;

==> react-molecule-image-editor-1.6.0.tgz: package/lib/index.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { useCallback, useState } from 'react';
import Cropper from 'react-easy-crop';
import PropTypes from 'prop-types';
import { debounce } from '@s-ui/js/lib/function/debounce.js';
import AtomSlider from '@s-ui/react-atom-slider';
import getCroppedImg from './utils/cropImage.js';
import { baseClass, DEBOUNCING_TIME, DEFAULT_ASPECT, noop } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var MoleculeImageEditor = function MoleculeImageEditor(_ref) {
  var _ref$aspect = _ref.aspect,
      aspect = _ref$aspect === void 0 ? DEFAULT_ASPECT : _ref$aspect,
      cropLabelIcon = _ref.cropLabelIcon,
      cropLabelText = _ref.cropLabelText,
      image = _ref.image,
      onChange = _ref.onChange,
      _ref$onCropping = _ref.onCropping,
      onCropping = _ref$onCropping === void 0 ? noop : _ref$onCropping,
      rotateLabelIcon = _ref.rotateLabelIcon,
      rotateLabelText = _ref.rotateLabelText;

  var _useState = useState({
    x: 0,
    y: 0
  }),
      crop = _useState[0],
      cropSetter = _useState[1];

  var _useState2 = useState(0),
      rotation = _useState2[0],
      rotationSetter = _useState2[1];

  var _useState3 = useState(0),
      zoom = _useState3[0],
      zoomSetter = _useState3[1];

  var setCrop = debounce(cropSetter, DEBOUNCING_TIME);
  var setRotation = debounce(rotationSetter, DEBOUNCING_TIME);
  var setZoom = debounce(zoomSetter, DEBOUNCING_TIME);

  var getRotationDegrees = function getRotationDegrees(rotation) {
    return rotation * 360 / 100;
  };

  var cropCompleteHandler = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(croppedArea, croppedAreaPixels) {
      var rotationDegrees, _yield$getCroppedImg, croppedImageUrl, croppedImageBlobObject;

      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              rotationDegrees = getRotationDegrees(rotation);
              onCropping(true);
              _context.next = 4;
              return getCroppedImg(image, croppedAreaPixels, rotationDegrees);

            case 4:
              _yield$getCroppedImg = _context.sent;
              croppedImageUrl = _yield$getCroppedImg[0];
              croppedImageBlobObject = _yield$getCroppedImg[1];
              onChange(croppedImageUrl, croppedImageBlobObject);
              onCropping(false);

            case 9:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function cropCompleteHandler(_x, _x2) {
      return _ref2.apply(this, arguments);
    };
  }();

  var onCropComplete = useCallback(debounce(cropCompleteHandler, DEBOUNCING_TIME), [rotation, onCropping, image, onChange]);
  return /*#__PURE__*/_jsxs("div", {
    className: baseClass,
    children: [/*#__PURE__*/_jsx("div", {
      className: baseClass + "-crop",
      children: /*#__PURE__*/_jsx(Cropper, {
        image: image,
        crop: crop,
        zoom: 1 + zoom / 100,
        rotation: getRotationDegrees(rotation),
        aspect: aspect,
        onCropChange: setCrop,
        onCropComplete: onCropComplete,
        onRotationChange: setRotation,
        onZoomChange: function onZoomChange(zoom) {
          return setZoom((zoom - 1) * 100);
        }
      })
    }), /*#__PURE__*/_jsxs("div", {
      className: baseClass + "-slider",
      children: [(cropLabelIcon || cropLabelText) && /*#__PURE__*/_jsxs("div", {
        className: baseClass + "-label",
        children: [cropLabelIcon && /*#__PURE__*/_jsx("span", {
          className: baseClass + "-labelIcon",
          children: cropLabelIcon
        }), cropLabelText && /*#__PURE__*/_jsx("span", {
          className: baseClass + "-labelText",
          children: cropLabelText
        })]
      }), /*#__PURE__*/_jsx(AtomSlider, {
        onChange: function onChange(event, _ref3) {
          var value = _ref3.value;
          return setZoom(value);
        },
        defaultValue: zoom,
        hideMarks: true
      })]
    }), /*#__PURE__*/_jsxs("div", {
      className: baseClass + "-slider",
      children: [(rotateLabelIcon || rotateLabelText) && /*#__PURE__*/_jsxs("div", {
        className: baseClass + "-label",
        children: [rotateLabelIcon && /*#__PURE__*/_jsx("span", {
          className: baseClass + "-labelIcon",
          children: rotateLabelIcon
        }), rotateLabelText && /*#__PURE__*/_jsx("span", {
          className: baseClass + "-labelText",
          children: rotateLabelText
        })]
      }), /*#__PURE__*/_jsx(AtomSlider, {
        onChange: function onChange(event, _ref4) {
          var value = _ref4.value;
          return setRotation(value);
        },
        defaultValue: rotation,
        hideMarks: true
      })]
    })]
  });
};

MoleculeImageEditor.displayName = 'MoleculeImageEditor';
export default MoleculeImageEditor;
